#[non_exhaustive]pub enum DevToolsMessage {
Listening,
ListeningWs,
}This is no longer necessary due to the NodeCliInspect fuse’s functionality.
List of known developer tool command line messages that can be written to stdout by Node.JS during debugging.
Warning
Disabling these is a worst-case fallback protection against internal changes to the way that Chromium/Electron/Node.JS handle parsing command line arguments. If something is changed and a debugging flag slips through, modifying one of these will cause the application to trigger a segemntation fault and be terminated by the OS, exiting immediately.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Listening
This is no longer necessary due to the NodeCliInspect fuse’s functionality.
The message printed to standard out when Node.JS listens on TCP port.
Ex: Debugger listening on 127.0.0.1:9229/uuid
ListeningWs
This is no longer necessary due to the NodeCliInspect fuse’s functionality.
The message printed to standard out when Node.JS listens on a websocket.
Ex: Debugger listening on ws://127.0.0.1:9229/uuid